@@ -92,7 +92,9 @@ sub ran_rule {
 
 sub finish {
 	my $self = shift;
-	$self->{'redis'}->quit;
+	if( defined $self->{'redis'} ) {
+		$self->{'redis'}->quit;
+	}
 	return;
 }
 
@@ -110,7 +112,7 @@ Mail::SpamAssassin::Plugin::RuleTimingRedis - collect SA rule timings in redis
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 DESCRIPTION
 
